# Pandas-Utilities

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

Pandas Utilities has some good attributes, functions and what not to make the developers task simpler.
Pandas Utilities is purely written in python3.

What you can do using Pandas Utilities?
  - Easy cleaning of Raw-Data
  - Extra Details about DataFrame
  - Single line printing
  - Count the number of Null Values for entire DataFrame
  - Delete Row if you want(While most of the collumn is null in any row)
  - Check Duplicate Rows in dataframe
  - Update Labels of DataFrame directly according to coding guidlines
 
### How to use/install pythonUtilities?

pythonUtilities is OS-independent and can work on python3 and above versions.
To Install pythonUtilities, you require "pip" installed on your machine.
If you don't have pip installed watch this [video](https://nodejs.org/) to install it on your machine.
If you have pip installed then go ahead.
Go to your cmd/powershell/terminal and run the below command for the latest version.
```sh
$ pip install pythonUtilities
```
OR
```sh
$ pip install pandasUtilities==0.0.1
```
For the specific version...


### Future Updates

 - There are no any updates yet.

License
----

MIT